@@ -1,7 +1,5 @@
-#include "bsdtar_platform.h"
-
+#include <stddef.h>
 #include <stdint.h>
-#include <string.h>
 
 #include "crypto_internal.h"
 #include "sha256.h"
@@ -10,7 +8,7 @@
 
 /**
  * crypto_hash_data_key(key, keylen, data, len, buf):
- * Hash the provided data with the provided HMAC-SHA256 key.
+ * Hash the provided ${data} with the provided HMAC-SHA256 ${key}.
  */
 void
 crypto_hash_data_key(const uint8_t * key, size_t keylen,
@@ -23,7 +21,7 @@ crypto_hash_data_key(const uint8_t * key, size_t keylen,
 
 /**
  * crypto_hash_data_key_2(key, keylen, data0, len0, data1, len1, buf):
- * Hash the concatenation of two buffers with the provided HMAC-SHA256 key.
+ * Hash the concatenation of two buffers with the provided HMAC-SHA256 ${key}.
  */
 void
 crypto_hash_data_key_2(const uint8_t * key, size_t keylen,
@@ -37,14 +35,11 @@ crypto_hash_data_key_2(const uint8_t * key, size_t keylen,
 	HMAC_SHA256_Update(&hctx, data0, len0);
 	HMAC_SHA256_Update(&hctx, data1, len1);
 	HMAC_SHA256_Final(buf, &hctx);
-
-	/* Clean the stack. */
-	memset(&hctx, 0, sizeof(HMAC_SHA256_CTX));
 }
 
 /**
  * crypto_hash_data(key, data, len, buf):
- * Hash the provided data with the HMAC-SHA256 key specified; or if
+ * Hash the provided ${data} with the HMAC-SHA256 ${key} specified; or if
  * ${key} == CRYPTO_KEY_HMAC_SHA256, just SHA256 the data.
  */
 int
@@ -73,9 +68,6 @@ crypto_hash_data_2(int key, const uint8_t * data0, size_t len0,
 		SHA256_Update(&ctx, data0, len0);
 		SHA256_Update(&ctx, data1, len1);
 		SHA256_Final(buf, &ctx);
-
-		/* Clean the stack. */
-		memset(&ctx, 0, sizeof(SHA256_CTX));
 	} else {
 		if ((hkey = crypto_keys_lookup_HMAC(key)) == NULL)
 			goto err0;
@@ -85,9 +77,6 @@ crypto_hash_data_2(int key, const uint8_t * data0, size_t len0,
 		HMAC_SHA256_Update(&hctx, data0, len0);
 		HMAC_SHA256_Update(&hctx, data1, len1);
 		HMAC_SHA256_Final(buf, &hctx);
-
-		/* Clean the stack. */
-		memset(&hctx, 0, sizeof(HMAC_SHA256_CTX));
 	}
 
 	/* Success! */
