@@ -3,9 +3,6 @@
 
 #include <stdint.h>
 
-#include <openssl/aes.h>
-#include <openssl/rsa.h>
-
 struct crypto_hmac_key {
 	size_t len;
 	uint8_t * key;
@@ -15,7 +12,7 @@ struct crypto_hmac_key {
  * crypto_keys_lookup_RSA(key):
  * Return the requested RSA key.
  */
-RSA * crypto_keys_lookup_RSA(int);
+void * crypto_keys_lookup_RSA(int);
 
 /**
  * crypto_keys_lookup_HMAC(key):
@@ -33,13 +30,13 @@ int crypto_keys_server_import_root(void);
  * crypto_keys_subr_import_RSA_priv(key, buf, buflen):
  * Import the specified RSA private key from the provided buffer.
  */
-int crypto_keys_subr_import_RSA_priv(RSA **, const uint8_t *, size_t);
+int crypto_keys_subr_import_RSA_priv(void **, const uint8_t *, size_t);
 
 /**
  * crypto_keys_subr_import_RSA_pub(key, buf, buflen):
  * Import the specified RSA public key from the provided buffer.
  */
-int crypto_keys_subr_import_RSA_pub(RSA **, const uint8_t *, size_t);
+int crypto_keys_subr_import_RSA_pub(void **, const uint8_t *, size_t);
 
 /**
  * crypto_keys_subr_import_HMAC(key, buf, buflen):
@@ -53,14 +50,14 @@ int crypto_keys_subr_import_HMAC(struct crypto_hmac_key **, const uint8_t *,
  * If buf != NULL, export the specified RSA private key.  Return the key
  * length in bytes.
  */
-uint32_t crypto_keys_subr_export_RSA_priv(RSA *, uint8_t *, size_t);
+uint32_t crypto_keys_subr_export_RSA_priv(void *, uint8_t *, size_t);
 
 /**
  * crypto_keys_subr_export_RSA_pub(key, buf, buflen):
  * If buf != NULL, export the specified RSA public key.  Return the key
  * length in bytes.
  */
-uint32_t crypto_keys_subr_export_RSA_pub(RSA *, uint8_t *, size_t);
+uint32_t crypto_keys_subr_export_RSA_pub(void *, uint8_t *, size_t);
 
 /**
  * crypto_keys_subr_export_HMAC(key, buf, buflen):
@@ -74,7 +71,7 @@ uint32_t crypto_keys_subr_export_HMAC(struct crypto_hmac_key *, uint8_t *,
  * crypto_keys_subr_generate_RSA(priv, pub):
  * Generate an RSA key and store the private and public parts.
  */
-int crypto_keys_subr_generate_RSA(RSA **, RSA **);
+int crypto_keys_subr_generate_RSA(void **, void **);
 
 /**
  * crypto_keys_subr_generate_HMAC(key):
