@@ -1,5 +1,3 @@
-#include "bsdtar_platform.h"
-
 #include <errno.h>
 #include <stdint.h>
 #include <stdlib.h>
@@ -9,6 +7,7 @@
 #include <openssl/rand.h>
 #include <openssl/rsa.h>
 
+#include "crypto_compat.h"
 #include "crypto_entropy.h"
 #include "sysendian.h"
 #include "warnp.h"
@@ -206,11 +205,8 @@ crypto_keys_atexit(void)
 	crypto_keys_subr_free_HMAC(&keycache.auth_get);
 	crypto_keys_subr_free_HMAC(&keycache.auth_delete);
 
-	/* Free OpenSSL error strings. */
-	ERR_free_strings();
-
-	/* A more general OpenSSL cleanup function. */
-	CRYPTO_cleanup_all_ex_data();
+	/* Free shared memory allocated by OpenSSL. */
+	crypto_compat_free();
 }
 
 /**
@@ -251,25 +247,25 @@ crypto_keys_import(const uint8_t * buf, size_t buflen, int keys)
 		case CRYPTO_KEY_SIGN_PRIV:
 			if ((keys & CRYPTO_KEYMASK_SIGN_PRIV) &&
 			    crypto_keys_subr_import_RSA_priv(
-			    &keycache.sign_priv, buf, len))
+			    (void**)&keycache.sign_priv, buf, len))
 				goto err0;
 			break;
 		case CRYPTO_KEY_SIGN_PUB:
 			if ((keys & CRYPTO_KEYMASK_SIGN_PUB) &&
 			    crypto_keys_subr_import_RSA_pub(
-			    &keycache.sign_pub, buf, len))
+			    (void**)&keycache.sign_pub, buf, len))
 				goto err0;
 			break;
 		case CRYPTO_KEY_ENCR_PRIV:
 			if ((keys & CRYPTO_KEYMASK_ENCR_PRIV) &&
 			    crypto_keys_subr_import_RSA_priv(
-			    &keycache.encr_priv, buf, len))
+			    (void**)&keycache.encr_priv, buf, len))
 				goto err0;
 			break;
 		case CRYPTO_KEY_ENCR_PUB:
 			if ((keys & CRYPTO_KEYMASK_ENCR_PUB) &&
 			    crypto_keys_subr_import_RSA_pub(
-			    &keycache.encr_pub, buf, len))
+			    (void**)&keycache.encr_pub, buf, len))
 				goto err0;
 			break;
 		case CRYPTO_KEY_HMAC_FILE:
@@ -277,6 +273,18 @@ crypto_keys_import(const uint8_t * buf, size_t buflen, int keys)
 			    crypto_keys_subr_import_HMAC(
 			    &keycache.hmac_file, buf, len))
 				goto err0;
+			/*
+			 * There is normally only one "file hmac" key, used for
+			 * both signing blocks which are being written and
+			 * verifying blocks which are being read; but in
+			 * tarsnap-recrypt we download blocks from one machine
+			 * and verify them with one key before re-uploading
+			 * them signed with a different key.  Consequently, the
+			 * tarsnap crypto code internally treats this as two
+			 * keys; and we set one or both to the key we're
+			 * reading from the key file depending on the flags we
+			 * were passed.
+			 */
 			if ((keys & CRYPTO_KEYMASK_HMAC_FILE_WRITE) &&
 			    crypto_keys_subr_import_HMAC(
 			    &keycache.hmac_file_write, buf, len))
@@ -303,7 +311,7 @@ crypto_keys_import(const uint8_t * buf, size_t buflen, int keys)
 		case CRYPTO_KEY_ROOT_PUB:
 			if ((keys & CRYPTO_KEYMASK_ROOT_PUB) &&
 			    crypto_keys_subr_import_RSA_pub(
-			    &keycache.root_pub, buf, len))
+			    (void**)&keycache.root_pub, buf, len))
 				goto err0;
 			break;
 		case CRYPTO_KEY_AUTH_PUT:
@@ -421,7 +429,7 @@ crypto_keys_missing(int keys)
 
 /**
  * crypto_keys_export(keys, buf, buflen):
- * Export the keys specified to a buffer allocated using malloc.
+ * Export the ${keys} specified to a buffer allocated using malloc.
  */
 int
 crypto_keys_export(int keys, uint8_t ** buf, size_t * buflen)
@@ -501,7 +509,7 @@ err0:
 
 /**
  * crypto_keys_generate(keys):
- * Create the keys specified.
+ * Create the ${keys} specified.
  */
 int
 crypto_keys_generate(int keys)
@@ -514,8 +522,8 @@ crypto_keys_generate(int keys)
 			    "private key", "public key");
 			goto err0;
 		}
-		if (crypto_keys_subr_generate_RSA(&keycache.sign_priv,
-		    &keycache.sign_pub))
+		if (crypto_keys_subr_generate_RSA((void *)&keycache.sign_priv,
+		    (void *)&keycache.sign_pub))
 			goto err0;
 
 		keys &= ~CRYPTO_KEYMASK_SIGN_PRIV;
@@ -534,8 +542,8 @@ crypto_keys_generate(int keys)
 			    "private key", "public key");
 			goto err0;
 		}
-		if (crypto_keys_subr_generate_RSA(&keycache.encr_priv,
-		    &keycache.encr_pub))
+		if (crypto_keys_subr_generate_RSA((void *)&keycache.encr_priv,
+		    (void *)&keycache.encr_pub))
 			goto err0;
 
 		keys &= ~CRYPTO_KEYMASK_ENCR_PRIV;
@@ -667,7 +675,7 @@ err0:
  * crypto_keys_lookup_RSA(key):
  * Return the requested RSA key.
  */
-RSA *
+void *
 crypto_keys_lookup_RSA(int key)
 {
 	RSA * rsa;
