@@ -1,5 +1,3 @@
-#include "bsdtar_platform.h"
-
 #include <assert.h>
 #include <limits.h>
 #include <stdint.h>
@@ -60,7 +58,7 @@ crypto_MGF1(uint8_t * seed, size_t seedlen, uint8_t * buf, size_t buflen)
 
 /**
  * crypto_rsa_sign(key, data, len, sig, siglen):
- * Sign the provided data with the specified key, writing the signature
+ * Sign the provided ${data} with the specified ${key}, writing the signature
  * into ${sig}.
  */
 int
@@ -150,8 +148,9 @@ err0:
 
 /**
  * crypto_rsa_verify(key, data, len, sig, siglen):
- * Verify that the provided signature matches the provided data.  Return 0
- * if the signature is valid, 1 if the signature is invalid, or -1 on error.
+ * Verify that the provided signature ${sig} matches the provided ${data}.
+ * Return 0 if the signature is valid, 1 if the signature is invalid, or -1
+ * on error.
  */
 int
 crypto_rsa_verify(int key, const uint8_t * data, size_t len,
@@ -271,8 +270,8 @@ err0:
 
 /**
  * crypto_rsa_encrypt(key, data, len, out, outlen):
- * Encrypt the provided data with the specified key, writing the ciphertext
- * into ${out} (of length ${outlen}).
+ * Encrypt the provided ${data} with the specified ${key}, writing the
+ * ciphertext into ${out} (of length ${outlen}).
  */
 int
 crypto_rsa_encrypt(int key, const uint8_t * data, size_t len,
@@ -361,10 +360,10 @@ err0:
 
 /**
  * crypto_rsa_decrypt(key, data, len, out, outlen):
- * Decrypt the provided data with the specified key, writing the ciphertext
- * into ${out} (of length ${outlen}).  Set ${*outlen} to the length of the
- * plaintext, and return 0 on success, 1 if the ciphertext is invalid, or
- * -1 on error.
+ * Decrypt the provided ${data} with the specified ${key}, writing the
+ * ciphertext into ${out} (of length ${*outlen}).  Set ${*outlen} to the
+ * length of the plaintext, and return 0 on success, 1 if the ciphertext is
+ * invalid, or 1 on error.
  */
 int
 crypto_rsa_decrypt(int key, const uint8_t * data, size_t len,
