@@ -1,5 +1,3 @@
-#include "bsdtar_platform.h"
-
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -15,6 +13,7 @@
 #include "b64encode.h"
 #include "crypto.h"
 #include "insecure_memzero.h"
+#include "passphrase_entry.h"
 #include "readpass.h"
 #include "scryptenc.h"
 #include "sysendian.h"
@@ -60,11 +59,11 @@ static int read_raw(const uint8_t *, size_t,
 static int read_plaintext(const uint8_t *, size_t,
     uint64_t *, const char *, int);
 static int read_encrypted(const uint8_t *, size_t,
-    uint64_t *, const char *, int, int);
+    uint64_t *, const char *, int, int, enum passphrase_entry, const char *);
 static int read_base256(const uint8_t *, size_t,
-    uint64_t *, const char *, int, int);
+    uint64_t *, const char *, int, int, enum passphrase_entry, const char *);
 static int read_base64(const char *, size_t,
-    uint64_t *, const char *, int, int);
+    uint64_t *, const char *, int, int, enum passphrase_entry, const char *);
 
 static int
 read_raw(const uint8_t * keybuf, size_t keylen, uint64_t * machinenum,
@@ -119,13 +118,15 @@ err0:
 
 static int
 read_encrypted(const uint8_t * keybuf, size_t keylen, uint64_t * machinenum,
-    const char * filename, int keys, int force)
+    const char * filename, int keys, int force,
+    enum passphrase_entry passphrase_entry, const char * passphrase_arg)
 {
 	char * pwprompt;
 	char * passwd;
 	uint8_t * deckeybuf;
 	size_t deckeylen;
 	int rc;
+	struct scryptenc_params params = {0, 0.5, 86400.0, 0, 0, 0};
 
 	/* The caller must pass a file name to be read. */
 	assert(filename != NULL);
@@ -140,7 +141,8 @@ read_encrypted(const uint8_t * keybuf, size_t keylen, uint64_t * machinenum,
 	if (asprintf(&pwprompt, "Please enter passphrase for keyfile %s",
 	    filename) == -1)
 		goto err0;
-	if (readpass(&passwd, pwprompt, NULL, 1)) {
+	if (passphrase_entry_readpass(&passwd, passphrase_entry,
+	    passphrase_arg, pwprompt, NULL, 1)) {
 		warnp("Error reading passphrase");
 		goto err1;
 	}
@@ -157,38 +159,41 @@ read_encrypted(const uint8_t * keybuf, size_t keylen, uint64_t * machinenum,
 
 	/* Decrypt the key file. */
 	rc = scryptdec_buf(keybuf, keylen, deckeybuf, &deckeylen,
-	    (const uint8_t *)passwd, strlen(passwd), 0, 0.5, 86400.0, 0,
+	    (const uint8_t *)passwd, strlen(passwd), &params, 0,
 	    force);
-	if (rc != 0) {
+	if (rc != SCRYPT_OK) {
 		switch (rc) {
-		case 1:
+		case SCRYPT_ELIMIT:
 			warnp("Error determining amount of available memory");
 			break;
-		case 2:
+		case SCRYPT_ECLOCK:
 			warnp("Error reading clocks");
 			break;
-		case 3:
+		case SCRYPT_EKEY:
 			warnp("Error computing derived key");
 			break;
-		case 5:
+		case SCRYPT_EOPENSSL:
 			warnp("OpenSSL error");
 			break;
-		case 6:
+		case SCRYPT_ENOMEM:
 			/* malloc failure */
 			break;
-		case 7:
+		case SCRYPT_EINVAL:
 			warn0("Input is not valid scrypt-encrypted block");
 			break;
-		case 8:
+		case SCRYPT_EVERSION:
 			warn0("Unrecognized scrypt format version");
 			break;
-		case 9:
+		case SCRYPT_ETOOBIG:
 			warn0("Decrypting file would require too much memory");
 			break;
-		case 10:
+		case SCRYPT_ETOOSLOW:
 			warn0("Decrypting file would take too much CPU time");
 			break;
-		case 11:
+		case SCRYPT_EBIGSLOW:
+			warn0("Decrypting file would take too much CPU time and memory");
+			break;
+		case SCRYPT_EPASS:
 			warn0("Passphrase is incorrect");
 			break;
 		default:
@@ -238,7 +243,8 @@ err0:
 
 static int
 read_base256(const uint8_t * keybuf, size_t keylen, uint64_t * machinenum,
-    const char * filename, int keys, int force)
+    const char * filename, int keys, int force,
+    enum passphrase_entry passphrase_entry, const char * passphrase_arg)
 {
 
 	/* Sanity-check size. */
@@ -250,7 +256,8 @@ read_base256(const uint8_t * keybuf, size_t keylen, uint64_t * machinenum,
 	/* Is this encrypted? */
 	if (memcmp(keybuf, "scrypt", 6) == 0)
 		return (read_encrypted(keybuf, keylen,
-		    machinenum, filename, keys, force));
+		    machinenum, filename, keys, force, passphrase_entry,
+		    passphrase_arg));
 
 	/* Parse this as a plaintext keyfile. */
 	return (read_plaintext(keybuf, keylen,
@@ -263,7 +270,8 @@ err0:
 
 static int
 read_base64(const char * keybuf, size_t keylen, uint64_t * machinenum,
-    const char * filename, int keys, int force)
+    const char * filename, int keys, int force,
+    enum passphrase_entry passphrase_entry, const char * passphrase_arg)
 {
 	uint8_t * decbuf;
 	size_t decbuflen;
@@ -297,13 +305,6 @@ read_base64(const char * keybuf, size_t keylen, uint64_t * machinenum,
 				break;
 		}
 
-		/* If we didn't find an EOL, the file is corrupt. */
-		if (llen == keylen) {
-			warn0("Key file is corrupt or truncated: %s",
-			    filename);
-			goto err1;
-		}
-
 		/* If this isn't a comment or blank line, base-64 decode it. */
 		if ((llen > 0) && (keybuf[0] != '#')) {
 			if (b64decode(keybuf, llen, &decbuf[decpos], &len))
@@ -333,19 +334,20 @@ read_base64(const char * keybuf, size_t keylen, uint64_t * machinenum,
 		keybuf += llen;
 		keylen -= llen;
 
-		/* Skip past the EOL. */
+		/* Skip past the EOL if we're not at EOF. */
 		if ((keylen > 1) &&
 		    (keybuf[0] == '\r') && (keybuf[1] == '\n')) {
 			keybuf += 2;
 			keylen -= 2;
-		} else {
+		} else if (keylen) {
 			keybuf += 1;
 			keylen -= 1;
 		}
 	}
 
 	/* Process the decoded key file. */
-	if (read_base256(decbuf, decpos, machinenum, filename, keys, force))
+	if (read_base256(decbuf, decpos, machinenum, filename, keys, force,
+	    passphrase_entry, passphrase_arg))
 		goto err1;
 
 	/* Zero and free memory. */
@@ -366,50 +368,57 @@ err0:
 }
 
 /**
- * keyfile_read(filename, machinenum, keys, force):
+ * keyfile_read(filename, machinenum, keys, force, passphrase_entry,
+ *     passphrase_arg):
  * Read keys from a tarsnap key file; and return the machine # via the
  * provided pointer.  Ignore any keys not specified in the ${keys} mask.
  * If ${force} is 1, do not check whether decryption will exceed
- * the estimated available memory or time.
+ * the estimated available memory or time.  Use the ${passphrase_entry}
+ * method to read the passphrase, using ${passphrase_arg} if applicable.
  */
 int
-keyfile_read(const char * filename, uint64_t * machinenum, int keys, int force)
+keyfile_read(const char * filename, uint64_t * machinenum, int keys, int force,
+    enum passphrase_entry passphrase_entry, const char * passphrase_arg)
 {
 	struct stat sb;
 	uint8_t * keybuf;
 	FILE * f;
 	size_t keyfilelen;
 
-	/* Stat the file. */
-	if (stat(filename, &sb)) {
-		warnp("stat(%s)", filename);
+	/* Open the file. */
+	if ((f = fopen(filename, "r")) == NULL) {
+		warnp("fopen(%s)", filename);
 		goto err0;
 	}
 
+	/* Stat the file. */
+	if (fstat(fileno(f), &sb)) {
+		warnp("stat(%s)", filename);
+		goto err1;
+	}
+
 	/* Validate keyfile size. */
 	if ((sb.st_size == 0) || (sb.st_size > 1000000)) {
 		warn0("Key file has unreasonable size: %s", filename);
-		goto err0;
+		goto err1;
 	}
 	keyfilelen = (size_t)(sb.st_size);
 
 	/* Allocate memory. */
 	if ((keybuf = malloc(keyfilelen)) == NULL)
-		goto err0;
+		goto err1;
 
 	/* Read the file. */
-	if ((f = fopen(filename, "r")) == NULL) {
-		warnp("fopen(%s)", filename);
-		goto err1;
-	}
 	if (fread(keybuf, keyfilelen, 1, f) != 1) {
 		warnp("fread(%s)", filename);
 		goto err2;
 	}
 	if (fclose(f)) {
 		warnp("fclose(%s)", filename);
-		goto err1;
+		f = NULL;
+		goto err2;
 	}
+	f = NULL;
 
 	/* If this is a raw key file, process it. */
 	if ((keybuf[0] == 0x00) || (keybuf[0] == 0xff)) {
@@ -417,15 +426,16 @@ keyfile_read(const char * filename, uint64_t * machinenum, int keys, int force)
 		    machinenum, filename, keys)) {
 			if (errno)
 				warnp("Error parsing key file: %s", filename);
-			goto err1;
+			goto err2;
 		}
 	} else {
 		/* Otherwise, try to base64 decode it. */
 		if (read_base64((const char *)keybuf, keyfilelen,
-		    machinenum, filename, keys, force)) {
+		    machinenum, filename, keys, force, passphrase_entry,
+		    passphrase_arg)) {
 			if (errno)
 				warnp("Error parsing key file: %s", filename);
-			goto err1;
+			goto err2;
 		}
 	}
 
@@ -437,10 +447,11 @@ keyfile_read(const char * filename, uint64_t * machinenum, int keys, int force)
 	return (0);
 
 err2:
-	fclose(f);
-err1:
 	insecure_memzero(keybuf, keyfilelen);
 	free(keybuf);
+err1:
+	if (f != NULL)
+		fclose(f);
 err0:
 	/* Failure! */
 	return (-1);
@@ -449,8 +460,8 @@ err0:
 /**
  * keyfile_write(filename, machinenum, keys, passphrase, maxmem, cputime):
  * Write a key file for the specified machine containing the specified keys.
- * If passphrase is non-NULL, use up to cputime seconds and maxmem bytes of
- * memory to encrypt the key file.
+ * If ${passphrase} is non-NULL, use up to ${cputime} seconds and ${maxmem}
+ * bytes of memory to encrypt the key file.
  */
 int
 keyfile_write(const char * filename, uint64_t machinenum, int keys,
@@ -515,6 +526,7 @@ keyfile_write_open(const char * filename)
 	return (f);
 
 err1:
+	unlink(filename);
 	close(fd);
 err0:
 	/* Failure! */
@@ -524,8 +536,8 @@ err0:
 /**
  * keyfile_write_file(f, machinenum, keys, passphrase, maxmem, cputime):
  * Write a key file for the specified machine containing the specified keys.
- * If passphrase is non-NULL, use up to cputime seconds and maxmem bytes of
- * memory to encrypt the key file.
+ * If ${passphrase} is non-NULL, use up to ${cputime} seconds and ${maxmem}
+ * bytes of memory to encrypt the key file.
  */
 int
 keyfile_write_file(FILE * f, uint64_t machinenum, int keys,
@@ -542,6 +554,8 @@ keyfile_write_file(FILE * f, uint64_t machinenum, int keys,
 	size_t writepos;
 	size_t linelen;
 	uint8_t hbuf[32];
+	double maxmemfrac = (maxmem != 0) ? 0.5 : 0.125;
+	struct scryptenc_params params = {maxmem, maxmemfrac, cputime, 0, 0, 0};
 
 	/* Export keys. */
 	if (crypto_keys_export(keys, &keybuf, &keybuflen)) {
@@ -572,26 +586,26 @@ keyfile_write_file(FILE * f, uint64_t machinenum, int keys,
 		/* Encrypt. */
 		switch ((rc = scryptenc_buf(tskeybuf, tskeylen, encrbuf,
 		    (uint8_t *)passphrase, strlen(passphrase),
-		    maxmem, (maxmem != 0) ? 0.5 : 0.125, cputime, 0))) {
-		case 0:
+		    &params, 0, 0))) {
+		case SCRYPT_OK:
 			/* Success! */
 			break;
-		case 1:
+		case SCRYPT_ELIMIT:
 			warnp("Error determining amount of available memory");
 			break;
-		case 2:
+		case SCRYPT_ECLOCK:
 			warnp("Error reading clocks");
 			break;
-		case 3:
+		case SCRYPT_EKEY:
 			warnp("Error computing derived key");
 			break;
-		case 4:
+		case SCRYPT_ESALT:
 			warnp("Error reading salt");
 			break;
-		case 5:
+		case SCRYPT_EOPENSSL:
 			warnp("OpenSSL error");
 			break;
-		case 6:
+		case SCRYPT_ENOMEM:
 			warnp("Error allocating memory");
 			break;
 		default:
@@ -601,7 +615,7 @@ keyfile_write_file(FILE * f, uint64_t machinenum, int keys,
 		}
 
 		/* Error out if the encryption failed. */
-		if (rc != 0) {
+		if (rc != SCRYPT_OK) {
 			insecure_memzero(encrbuf, tskeylen + 128);
 			free(encrbuf);
 			goto err2;
