@@ -1,5 +1,3 @@
-#include "bsdtar_platform.h"
-
 #include <stdint.h>
 #include <string.h>
 
@@ -7,7 +5,6 @@
 #include "netpacket_internal.h"
 #include "netproto.h"
 #include "sysendian.h"
-#include "warnp.h"
 
 #include "netpacket.h"
 
