@@ -1,5 +1,3 @@
-#include "bsdtar_platform.h"
-
 #include <errno.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -34,6 +32,7 @@ _netproto_printerr(int status)
 	case NETWORK_STATUS_TIMEOUT:
 		/* Server timed out. */
 		warn0("Timeout communicating with server");
+		break;
 	case NETWORK_STATUS_CTIMEOUT:
 		/* Server timed out. */
 		warn0("Timeout connecting to server");
@@ -119,7 +118,7 @@ err0:
 /**
  * netproto_getstats(C, in, out, queued):
  * Obtain the number of bytes received and sent via the connection, and the
- * number of bytes queued to be written.
+ * number of bytes ${queued} to be written.
  */
 void
 netproto_getstats(NETPROTO_CONNECTION * C, uint64_t * in, uint64_t * out,
@@ -260,7 +259,7 @@ netproto_close(NETPROTO_CONNECTION * C)
 		if (errno == ECONNRESET) {
 			/*
 			 * You can't dump me!  I'm dumping you!  We don't
-			 * care about the connection dying since we we're
+			 * care about the connection dying since we're
 			 * done with it anyway.
 			 */
 			break;
