@@ -23,20 +23,6 @@
 	}					\
 } while (0)
 
-/**
- * network_cork(fd):
- * Clear the TCP_NODELAY socket option, and set TCP_CORK or TCP_NOPUSH if
- * either is defined.
- */
-int network_cork(int);
-
-/**
- * network_uncork(fd):
- * Set the TCP_NODELAY socket option, and clear TCP_CORK or TCP_NOPUSH if
- * either is defined.
- */
-int network_uncork(int);
-
 /**
  * network_register_suspend(op):
  * Suspend ${op} operations, on all file descriptors.
@@ -73,4 +59,4 @@ int network_bwlimit_get(int, size_t *);
  */
 int network_bwlimit_eat(int, size_t);
 
-#endif /* !_NETWORK_H_ */
+#endif /* !_NETWORK_INTERNAL_H_ */
