@@ -2,7 +2,6 @@
 
 #include <assert.h>
 #include <stdlib.h>
-#include <string.h>
 
 #include "elasticarray.h"
 #include "events.h"
@@ -36,7 +35,7 @@ op2cs(int op)
 	case NETWORK_OP_WRITE:
 		return (1);
 	default:
-		assert(!"Invalid operation type in network_register");
+		assert(0 && "Invalid operation type in network_register");
 	}
 }
 
@@ -69,7 +68,7 @@ docallback(struct callback * c, int timedout)
 		status = NETWORK_STATUS_TIMEOUT;
 		break;
 	default:
-		assert(!"Invalid status to docallback");
+		assert(0 && "Invalid status to docallback");
 		return (-1);
 	}
 
@@ -140,17 +139,17 @@ network_register(int fd, int op, struct timeval * timeo,
 	/* Enlarge array if necessary. */
 	if ((osize = (int)callbacks_getsize(cs)) <= fd) {
 		/* Resize. */
-		if (callbacks_resize(cs, fd + 1))
+		if (callbacks_resize(cs, (size_t)(fd + 1)))
 			goto err0;
 
 		/* Initialize empty. */
 		for (; osize < fd + 1; osize++) {
-			*callbacks_get(cs, osize) = NULL;
+			*callbacks_get(cs, (size_t)osize) = NULL;
 		}
 	}
 
 	/* Grab the relevant callback record. */
-	c = *callbacks_get(cs, fd);
+	c = *callbacks_get(cs, (size_t)fd);
 
 	/* If there is no record in that slot, allocate one. */
 	if (c == NULL) {
@@ -164,7 +163,7 @@ network_register(int fd, int op, struct timeval * timeo,
 		c->event_timer = NULL;
 
 		/* Insert into table slot. */
-		*callbacks_get(cs, fd) = c;
+		*callbacks_get(cs, (size_t)fd) = c;
 	}
 
 	/* Make sure we're not replacing an existing callback. */
@@ -233,7 +232,7 @@ network_deregister(int fd, int op)
 	}
 
 	/* Grab the relevant callback record. */
-	c = *callbacks_get(cs, fd);
+	c = *callbacks_get(cs, (size_t)fd);
 
 	/* If there is no callback, return silently. */
 	if (c == NULL || c->callback == NULL)
