@@ -1003,9 +1003,10 @@ restore_entry(struct archive_write_disk *a)
 		if ((a->flags & ARCHIVE_EXTRACT_NO_OVERWRITE_NEWER)
 		    &&  !S_ISDIR(a->st.st_mode)) {
 			if (!older(&(a->st), a->entry)) {
+				archive_entry_unset_size(a->entry);
 				archive_set_error(&a->archive, 0,
 				    "File on disk is not older; skipping.");
-				return (ARCHIVE_FAILED);
+				return (ARCHIVE_OK);
 			}
 		}
 
@@ -1097,7 +1098,7 @@ create_filesystem_object(struct archive_write_disk *a)
 		if (r == 0 && a->filesize <= 0) {
 			a->todo = 0;
 			a->deferred = 0;
-		} if (r == 0 && a->filesize > 0) {
+		} else if (r == 0 && a->filesize > 0) {
 			a->fd = open(a->name, O_WRONLY | O_TRUNC | O_BINARY);
 			if (a->fd < 0)
 				r = errno;
