@@ -82,6 +82,7 @@ __FBSDID("$FreeBSD: src/usr.bin/tar/bsdtar.c,v 1.93 2008/11/08 04:43:24 kientzle
 #include "dirutil.h"
 #include "humansize.h"
 #include "keyfile.h"
+#include "passphrase_entry.h"
 #include "tarsnap_opt.h"
 #include "tsnetwork.h"
 #include "warnp.h"
@@ -175,6 +176,7 @@ bsdtar_init(void)
 	bsdtar->conf_arg = NULL;
 	bsdtar->conffile_actual = NULL;
 	bsdtar->conffile_buffer = NULL;
+	bsdtar->option_passphrase_arg = NULL;
 
 	/* Initialize temporary tapenames array. */
 	bsdtar->tapenames_setup = strlist_init(0);
@@ -203,7 +205,7 @@ bsdtar_atexit(void)
 		strlist_free(bsdtar->tapenames_setup);
 	}
 
-	/* Free arrays containined strings allocated by strdup. */
+	/* Free arrays containing strings allocated by strdup. */
 	if (bsdtar->tapenames != NULL) {
 		for (i = 0; i < bsdtar->ntapes; i++)
 			free(bsdtar->tapenames[i]);
@@ -221,6 +223,7 @@ bsdtar_atexit(void)
 	free(bsdtar->conffile);
 	free(bsdtar->conf_opt);
 	free(bsdtar->conf_arg);
+	free(bsdtar->option_passphrase_arg);
 
 	/* Free file-parsing variables from util.c. */
 	free(bsdtar->conffile_buffer);
@@ -249,7 +252,8 @@ main(int argc, char **argv)
 	struct passwd		*pws;
 	const char		*missingkey;
 	time_t			 now;
-	size_t 			 i;
+	size_t			 i;
+	int			 j;
 	char			*tapename_cmdline;
 
 	WARNP_INIT;
@@ -282,6 +286,9 @@ main(int argc, char **argv)
 	/* We don't have a machine # yet. */
 	bsdtar->machinenum = (uint64_t)(-1);
 
+	/* We don't have any passphrase entry method yet. */
+	bsdtar->option_passphrase_entry = PASSPHRASE_UNSET;
+
 	/* Allocate space for config file names; at most argc of them. */
 	if ((bsdtar->configfiles = malloc(argc * sizeof(const char *))) == NULL)
 		bsdtar_errc(bsdtar, 1, ENOMEM, "Cannot allocate memory");
@@ -307,7 +314,7 @@ main(int argc, char **argv)
 	 * downside to this is a slight performance cost; but we don't write
 	 * enough data to stdout for that to matter.
 	 */
-	setvbuf(stdout, NULL, _IONBF, 0);
+	setvbuf(stdout, NULL, _IOLBF, 0);
 
 	/*
 	 * Unless specified otherwise, we consider ourselves to be
@@ -361,6 +368,17 @@ main(int argc, char **argv)
 	bsdtar->delopt = NULL;
 	bsdtar->delopt_tail = &bsdtar->delopt;
 
+	/* Check if any argument is --dump-config; if so, print them all. */
+	for (j = 0; j < argc; j++)
+		if (strcmp("--dump-config", bsdtar->argv[j]) == 0)
+			bsdtar->option_dump_config = 1;
+	if (bsdtar->option_dump_config) {
+		fprintf(stderr, "Command-line:\n ");
+		for (j = 0; j < argc; j++)
+			fprintf(stderr, " %s", argv[j]);
+		fprintf(stderr, "\n");
+	}
+
 	/*
 	 * Comments following each option indicate where that option
 	 * originated:  SUSv2, POSIX, GNU tar, star, etc.  If there's
@@ -433,6 +451,12 @@ main(int argc, char **argv)
 		case 'd': /* multitar */
 			set_mode(bsdtar, opt, "-d");
 			break;
+		case OPTION_DEBUG_NETWORK_STATS: /* tarsnap, developers only. */
+			tarsnap_opt_debug_network_stats = 1;
+			break;
+		case OPTION_DUMP_CONFIG: /* tarsnap */
+			/* Do nothing; already handled. */
+			break;
 		case OPTION_DISK_PAUSE: /* tarsnap */
 			optq_push(bsdtar, "disk-pause", bsdtar->optarg);
 			break;
@@ -549,7 +573,10 @@ main(int argc, char **argv)
 		 * TODO: Add corresponding "older" options to reverse these.
 		 */
 		case OPTION_NEWER_CTIME: /* GNU tar */
-			bsdtar->newer_ctime_sec = get_date(now, bsdtar->optarg);
+			if ((bsdtar->newer_ctime_sec =
+			    get_date(now, bsdtar->optarg)) == -1)
+				bsdtar_errc(bsdtar, 1, EINVAL,
+				    "Could not parse date");
 			break;
 		case OPTION_NEWER_CTIME_THAN:
 			{
@@ -563,7 +590,10 @@ main(int argc, char **argv)
 			}
 			break;
 		case OPTION_NEWER_MTIME: /* GNU tar */
-			bsdtar->newer_mtime_sec = get_date(now, bsdtar->optarg);
+			if ((bsdtar->newer_mtime_sec =
+			    get_date(now, bsdtar->optarg)) == -1)
+				bsdtar_errc(bsdtar, 1, EINVAL,
+				    "Could not parse date");
 			break;
 		case OPTION_NEWER_MTIME_THAN:
 			{
@@ -602,6 +632,7 @@ main(int argc, char **argv)
 			break;
 		case OPTION_NO_FORCE_RESOURCES:
 			optq_push(bsdtar, "no-force-resources", NULL);
+			break;
 		case OPTION_NO_HUMANIZE_NUMBERS:
 			optq_push(bsdtar, "no-humanize-numbers", NULL);
 			break;
@@ -626,6 +657,9 @@ main(int argc, char **argv)
 		case OPTION_NO_PRINT_STATS:
 			optq_push(bsdtar, "no-print-stats", NULL);
 			break;
+		case OPTION_NO_PROGRESS_BYTES: /* tarsnap */
+			optq_push(bsdtar, "no-progress-bytes", NULL);
+			break;
 		case OPTION_NO_QUIET:
 			optq_push(bsdtar, "no-quiet", NULL);
 			break;
@@ -679,9 +713,15 @@ main(int argc, char **argv)
 			bsdtar->extract_flags |= ARCHIVE_EXTRACT_XATTR;
 			bsdtar->extract_flags |= ARCHIVE_EXTRACT_FFLAGS;
 			break;
+		case OPTION_PASSPHRASE: /* tarsnap */
+			optq_push(bsdtar, "passphrase", bsdtar->optarg);
+			break;
 		case OPTION_PRINT_STATS: /* multitar */
 			bsdtar->option_print_stats = 1;
 			break;
+		case OPTION_PROGRESS_BYTES: /* tarsnap */
+			optq_push(bsdtar, "progress-bytes", bsdtar->optarg);
+			break;
 		case 'q': /* FreeBSD GNU tar --fast-read, NetBSD -q */
 			bsdtar->option_fast_read = 1;
 			break;
@@ -694,6 +734,9 @@ main(int argc, char **argv)
 		case OPTION_RECOVER:
 			set_mode(bsdtar, opt, "--recover");
 			break;
+		case OPTION_RESUME_EXTRACT:
+			bsdtar->option_resume_extract = 1;
+			break;
 		case OPTION_RETRY_FOREVER:
 			optq_push(bsdtar, "retry-forever", NULL);
 			break;
@@ -789,6 +832,14 @@ main(int argc, char **argv)
 	if ((bsdtar->mode == '\0') && (bsdtar->option_print_stats == 1))
 		set_mode(bsdtar, OPTION_PRINT_STATS, "--print-stats");
 
+	/*
+	 * We can reuse the --verify-config mode for --dump-config.
+	 * These lines must come after --print-stats, in case somebody wishes
+	 * to see the config that's being used for the --print-stats mode.
+	 */
+	if ((bsdtar->mode == '\0') && (bsdtar->option_dump_config == 1))
+		set_mode(bsdtar, OPTION_VERIFY_CONFIG, "--verify-config");
+
 	/* If no "real" mode was specified, treat -h as --help. */
 	if ((bsdtar->mode == '\0') && possible_help_request) {
 		long_help(bsdtar);
@@ -928,6 +979,15 @@ main(int argc, char **argv)
 	if (bsdtar->option_null)
 		only_mode(bsdtar, "--null", "cxt");
 
+	/* We should only have remaining args in -c, -t, and -x modes. */
+	if (bsdtar->argc != 0) {
+		if (!((bsdtar->mode == 'c') || (bsdtar->mode == 't') ||
+		    (bsdtar->mode == 'x'))) {
+			bsdtar_errc(bsdtar, 1, 0, "Cannot have unused "
+			    "command-line args in this mode.");
+		}
+	}
+
 	/* Check options only permitted in certain modes. */
 	if (bsdtar->option_dont_traverse_mounts)
 		only_mode(bsdtar, "--one-file-system", "c");
@@ -959,18 +1019,24 @@ main(int argc, char **argv)
 	if (bsdtar->mode == OPTION_VERIFY_CONFIG)
 		exit(0);
 
+	/*
+	 * Special case: if we're doing a dryrun and the keyfile came
+	 * from a config file, ignore a non-existent keyfile.
+	 */
+	if (bsdtar->keyfile && bsdtar->keyfile_from_config &&
+	    bsdtar->option_dryrun && (access(bsdtar->keyfile, F_OK) == -1)) {
+		free(bsdtar->keyfile);
+		bsdtar->keyfile = NULL;
+		bsdtar->config_file_keyfile_failed = 1;
+	}
+
 	/* Attempt to load keyfile. */
 	if (bsdtar->keyfile != NULL) {
 		if (load_keys(bsdtar, bsdtar->keyfile) == 0)
 			bsdtar->have_keys = 1;
 		else {
-			if (bsdtar->option_dryrun &&
-			    bsdtar->keyfile_from_config)
-				bsdtar->config_file_keyfile_failed = 1;
-			else {
-				bsdtar_errc(bsdtar, 1, errno,
-				    "Cannot read key file: %s", bsdtar->keyfile);
-			}
+			bsdtar_errc(bsdtar, 1, errno,
+			    "Cannot read key file: %s", bsdtar->keyfile);
 		}
 	}
 
@@ -1281,6 +1347,10 @@ configfile(struct bsdtar *bsdtar, const char *fname, int fromcmdline)
 {
 	struct stat sb;
 
+	/* Print config filename if given --dump-config. */
+	if (bsdtar->option_dump_config)
+		fprintf(stderr, "Reading from config file: %s\n", fname);
+
 	/*
 	 * If we had --no-config-exclude (or --no-config-include) earlier,
 	 * we do not want to process any --exclude (or --include) options
@@ -1339,6 +1409,10 @@ configfile_helper(struct bsdtar *bsdtar, const char *line)
 	if ((line[0] == '#') || (line[0] == '\0'))
 		return (0);
 
+	/* Print line if given --dump-config. */
+	if (bsdtar->option_dump_config)
+		fprintf(stderr, "  %s\n", line);
+
 	/* Duplicate line. */
 	if ((bsdtar->conf_opt = strdup(line)) == NULL)
 		bsdtar_errc(bsdtar, 1, errno, "Out of memory");
@@ -1381,8 +1455,9 @@ configfile_helper(struct bsdtar *bsdtar, const char *line)
 	}
 
 	/*
-	 * If we have an argument which starts with ~, and ${HOME} is
-	 * defined, expand ~ to $HOME.
+	 * If we have an argument which starts with ~, and the password
+	 * database lists a home directory for the user, expand ~ to that
+	 * value.
 	 */
 	if ((conf_arg != NULL) && (conf_arg[0] == '~') &&
 	    (bsdtar->homedir != NULL)) {
@@ -1482,6 +1557,7 @@ dooption(struct bsdtar *bsdtar, const char * conf_opt,
     const char * conf_arg, int fromconffile)
 {
 	struct stat st;
+	const char * str;
 	char *eptr;
 
 	if (strcmp(conf_opt, "aggressive-networking") == 0) {
@@ -1524,6 +1600,12 @@ dooption(struct bsdtar *bsdtar, const char * conf_opt,
 			goto needarg;
 
 		bsdtar->disk_pause = strtol(conf_arg, NULL, 0);
+		if (bsdtar->disk_pause > 1000)
+			bsdtar_errc(bsdtar, 1, 0,
+			    "disk-pause value must be <= 1000");
+		if (bsdtar->disk_pause < 0)
+			bsdtar_errc(bsdtar, 1, 0,
+			    "disk-pause value must be >= 0");
 		bsdtar->option_disk_pause_set = 1;
 	} else if (strcmp(conf_opt, "exclude") == 0) {
 		if (bsdtar->option_no_config_exclude_set)
@@ -1705,6 +1787,11 @@ dooption(struct bsdtar *bsdtar, const char * conf_opt,
 			goto optset;
 
 		bsdtar->option_print_stats_set = 1;
+	} else if (strcmp(conf_opt, "no-progress-bytes") == 0) {
+		if (bsdtar->option_progress_bytes_set)
+			goto optset;
+
+		bsdtar->option_progress_bytes_set = 1;
 	} else if (strcmp(conf_opt, "no-quiet") == 0) {
 		if (bsdtar->option_quiet_set)
 			goto optset;
@@ -1738,6 +1825,32 @@ dooption(struct bsdtar *bsdtar, const char * conf_opt,
 
 		bsdtar->option_print_stats = 1;
 		bsdtar->option_print_stats_set = 1;
+	} else if (strcmp(conf_opt, "passphrase") == 0) {
+		if (bsdtar->option_passphrase_entry != PASSPHRASE_UNSET)
+			goto optset;
+
+		if (passphrase_entry_parse(conf_arg,
+		    &bsdtar->option_passphrase_entry, &str))
+			bsdtar_errc(bsdtar, 1, 0, "Cannot parse passphrase"
+			    "entry method: %s", conf_arg);
+		if ((bsdtar->option_passphrase_arg = strdup(str)) == NULL)
+			bsdtar_errc(bsdtar, 1, ENOMEM,
+			    "Cannot allocate memory");
+	} else if (strcmp(conf_opt, "progress-bytes") == 0) {
+		if (!((bsdtar->mode != 'c') || (bsdtar->mode != 'x')))
+			goto badmode;
+		if (bsdtar->option_progress_bytes_set)
+			goto optset;
+		if (conf_arg == NULL)
+			goto needarg;
+
+		if (humansize_parse(conf_arg, &bsdtar->option_progress_bytes))
+			bsdtar_errc(bsdtar, 1, 0, "Cannot parse #bytes per"
+			    " progress message: %s", conf_arg);
+		if (bsdtar->option_progress_bytes < 1000)
+			bsdtar_errc(bsdtar, 1, 0, "progress-bytes value"
+			    " must be at least 1000");
+		bsdtar->option_progress_bytes_set = 1;
 	} else if (strcmp(conf_opt, "quiet") == 0) {
 		if (bsdtar->option_quiet_set)
 			goto optset;
@@ -1825,8 +1938,13 @@ load_keys(struct bsdtar *bsdtar, const char *path)
 {
 	uint64_t machinenum;
 
+	/* Set passphrase entry method (if unset). */
+	if (bsdtar->option_passphrase_entry == PASSPHRASE_UNSET)
+		bsdtar->option_passphrase_entry = PASSPHRASE_TTY_STDIN;
+
 	/* Load the key file. */
-	if (keyfile_read(path, &machinenum, ~0, bsdtar->option_force_resources))
+	if (keyfile_read(path, &machinenum, ~0, bsdtar->option_force_resources,
+	    bsdtar->option_passphrase_entry, bsdtar->option_passphrase_arg))
 		goto err0;
 
 	/* Check the machine number. */
