@@ -36,6 +36,7 @@
 #include <stdio.h>
 
 #include "elasticarray.h"
+#include "passphrase_entry.h"
 
 ELASTICARRAY_DECL(STRLIST, strlist, char *);
 
@@ -84,6 +85,7 @@ struct bsdtar {
 	char		  option_null; /* --null */
 	char		  option_numeric_owner; /* --numeric-owner */
 	char		  option_print_stats; /* --print-stats */
+	uint64_t	  option_progress_bytes; /* --progress-bytes */
 	char		  option_stdout; /* -O */
 	char		  option_store_atime; /* --store-atime */
 	char		  option_totals; /* --totals */
@@ -98,12 +100,14 @@ struct bsdtar {
 	int		  option_archive_names_set;
 	int		  option_cachecrunch_set;
 	int		  option_disk_pause_set;
+	int		  option_dump_config;
 	int		  option_humanize_numbers_set;
 	int		  option_maxbw_set;
 	int		  option_maxbw_rate_down_set;
 	int		  option_maxbw_rate_up_set;
 	int		  option_nodump_set;
 	int		  option_print_stats_set;
+	int		  option_progress_bytes_set;
 	int		  option_snaptime_set;
 	int		  option_store_atime_set;
 	int		  option_totals_set;
@@ -114,6 +118,7 @@ struct bsdtar {
 	int		  option_quiet;
 	int		  option_quiet_set;
 	int		  option_retry_forever_set;
+	int		  option_resume_extract;
 	int		  option_insane_filesystems;
 	int		  option_insane_filesystems_set;
 	int		  option_iso_dates;
@@ -121,10 +126,12 @@ struct bsdtar {
 	int		  option_force_resources;
 	int		  option_force_resources_set;
 	const char	**configfiles;		/* --configfile */
-	size_t 		  nconfigfiles;
+	size_t		  nconfigfiles;
 	int		  option_no_default_config; /* --no-default-config */
 	char		 *keyfile;
 	int		  keyfile_from_config;
+	char		 *option_passphrase_arg;
+	enum passphrase_entry option_passphrase_entry;
 
 	/* Miscellaneous state information */
 	struct archive	 *archive;
@@ -193,8 +200,10 @@ enum {
 	OPTION_CONFIGFILE,
 	OPTION_CREATIONTIME,
 	OPTION_CSV_FILE,
+	OPTION_DEBUG_NETWORK_STATS,
 	OPTION_DISK_PAUSE,
 	OPTION_DRYRUN,
+	OPTION_DUMP_CONFIG,
 	OPTION_EXCLUDE,
 	OPTION_FORCE_RESOURCES,
 	OPTION_FSCK,
@@ -235,6 +244,7 @@ enum {
 	OPTION_NO_MAXBW_RATE_UP,
 	OPTION_NO_NODUMP,
 	OPTION_NO_PRINT_STATS,
+	OPTION_NO_PROGRESS_BYTES,
 	OPTION_NO_QUIET,
 	OPTION_NO_RETRY_FOREVER,
 	OPTION_NO_SAME_OWNER,
@@ -248,10 +258,13 @@ enum {
 	OPTION_NULL,
 	OPTION_NUMERIC_OWNER,
 	OPTION_ONE_FILE_SYSTEM,
+	OPTION_PASSPHRASE,
 	OPTION_PRINT_STATS,
+	OPTION_PROGRESS_BYTES,
 	OPTION_RECOVER,
 	OPTION_RECOVER_DELETE,	/* Operation mode, not a real option */
 	OPTION_RECOVER_WRITE,	/* Operation mode, not a real option */
+	OPTION_RESUME_EXTRACT,
 	OPTION_RETRY_FOREVER,
 	OPTION_QUIET,
 	OPTION_SNAPTIME,
@@ -284,8 +297,9 @@ void	safe_fprintf(FILE *, const char *fmt, ...);
 void	set_chdir(struct bsdtar *, const char *newdir);
 void	siginfo_init(struct bsdtar *);
 void	siginfo_setinfo(struct bsdtar *, const char * oper,
-	    const char * path, int64_t size);
-void	siginfo_printinfo(struct bsdtar *, off_t progress);
+	    const char * path, int64_t size, int file_count,
+	    int64_t archive_uncompressed);
+void	siginfo_printinfo(struct bsdtar *, off_t progress, int finalmsg);
 void	siginfo_done(struct bsdtar *);
 void	tarsnap_mode_print_stats(struct bsdtar *bsdtar);
 void	tarsnap_mode_c(struct bsdtar *bsdtar);
@@ -308,3 +322,6 @@ void	add_substitution(struct bsdtar *, const char *);
 int	apply_substitution(struct bsdtar *, const char *, char **, int);
 void	cleanup_substitution(struct bsdtar *);
 #endif
+
+void	list_item_verbose(struct bsdtar *, FILE *,
+		    struct archive_entry *);
