@@ -1,7 +1,7 @@
-#include "bsdtar_platform.h"
+#include "platform.h"
 
-#include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 
 #include <assert.h>
 #include <errno.h>
@@ -14,6 +14,7 @@
 #include <string.h>
 #include <unistd.h>
 
+#include "asprintf.h"
 #include "ctassert.h"
 #include "dirutil.h"
 #include "rwhashtab.h"
@@ -175,6 +176,13 @@ chunks_directory_read(const char * cachepath, void ** dir,
 		goto err2;
 	}
 
+	/* Make sure the directory file isn't too small (different message). */
+	if ((size_t)sb.st_size < sizeof(struct chunkstats_external)) {
+		warn0("on-disk directory is too small (%jd bytes): %s",
+		    (intmax_t)(sb.st_size), s);
+		goto err2;
+	}
+
 	/* Make sure the number of chunks is an integer. */
 	if (((size_t)sb.st_size - sizeof(struct chunkstats_external)) %
 	    (sizeof(struct chunkdata_external))) {
