@@ -1,7 +1,7 @@
-#include "bsdtar_platform.h"
+#include "platform.h"
 
-#include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 
 #include <errno.h>
 #include <fcntl.h>
