@@ -80,10 +80,12 @@ static struct option {
 	{ "create",               0, 'c' },
 	{ "creationtime",         1, OPTION_CREATIONTIME },
 	{ "csv-file",		  1, OPTION_CSV_FILE },
+	{ "debug-network-stats",  0, OPTION_DEBUG_NETWORK_STATS },
 	{ "dereference",	  0, 'L' },
 	{ "directory",            1, 'C' },
 	{ "disk-pause",		  1, OPTION_DISK_PAUSE },
 	{ "dry-run",		  0, OPTION_DRYRUN },
+	{ "dump-config",	  0, OPTION_DUMP_CONFIG },
 	{ "exclude",              1, OPTION_EXCLUDE },
 	{ "exclude-from",         1, 'X' },
 	{ "extract",              0, 'x' },
@@ -120,7 +122,7 @@ static struct option {
 	{ "newer-mtime-than",	  1, OPTION_NEWER_MTIME_THAN },
 	{ "newer-than",		  1, OPTION_NEWER_CTIME_THAN },
 	{ "nodump",               0, OPTION_NODUMP },
-	{ "noisy-warnings", 	  0, OPTION_NOISY_WARNINGS },
+	{ "noisy-warnings",	  0, OPTION_NOISY_WARNINGS },
 	{ "norecurse",            0, 'n' },
 	{ "normalmem",		  0, OPTION_NORMALMEM },
 	{ "no-aggressive-networking", 0, OPTION_NO_AGGRESSIVE_NETWORKING },
@@ -137,6 +139,7 @@ static struct option {
 	{ "no-maxbw-rate-up",	  0, OPTION_NO_MAXBW_RATE_UP },
 	{ "no-nodump",		  0, OPTION_NO_NODUMP },
 	{ "no-print-stats",	  0, OPTION_NO_PRINT_STATS },
+	{ "no-progress-bytes",	  0, OPTION_NO_PROGRESS_BYTES },
 	{ "no-quiet",		  0, OPTION_NO_QUIET },
 	{ "no-recursion",         0, 'n' },
 	{ "no-retry-forever",	  0, OPTION_NO_RETRY_FOREVER },
@@ -149,11 +152,13 @@ static struct option {
 	{ "null",		  0, OPTION_NULL },
 	{ "numeric-owner",	  0, OPTION_NUMERIC_OWNER },
 	{ "one-file-system",	  0, OPTION_ONE_FILE_SYSTEM },
+	{ "passphrase",		  1, OPTION_PASSPHRASE },
 	{ "preserve-permissions", 0, 'p' },
 	{ "print-stats",	  0, OPTION_PRINT_STATS },
 	{ "quiet",		  0, OPTION_QUIET },
 	{ "read-full-blocks",	  0, 'B' },
 	{ "recover",		  0, OPTION_RECOVER },
+	{ "resume-extract",	  0, OPTION_RESUME_EXTRACT },
 	{ "retry-forever",	  0, OPTION_RETRY_FOREVER },
 	{ "same-owner",	          0, OPTION_SAME_OWNER },
 	{ "same-permissions",     0, 'p' },
@@ -164,6 +169,7 @@ static struct option {
 	{ "totals",		  0, OPTION_TOTALS },
 	{ "unlink",		  0, 'U' },
 	{ "unlink-first",	  0, 'U' },
+	{ "progress-bytes",	  1, OPTION_PROGRESS_BYTES },
 	{ "verify-config",	  0, OPTION_VERIFY_CONFIG },
 	{ "verbose",              0, 'v' },
 	{ "version",              0, OPTION_VERSION },
