@@ -1,4 +1,4 @@
-#include "bsdtar_platform.h"
+#include "platform.h"
 
 #include <stdint.h>
 #include <stdio.h>
@@ -142,11 +142,11 @@ deletetape(TAPE_D * d, uint64_t machinenum, const char * cachedir,
 
 	/* Print statistics if they were requested. */
 	if (printstats != 0) {
-		if (csv && (output = fopen(csv_filename, "wt")) == NULL)
+		if (csv && (output = fopen(csv_filename, "w")) == NULL)
 			goto err3;
 
 		/* Actually print statistics. */
-	    	if (chunks_delete_printstats(output, C,
+		if (chunks_delete_printstats(output, C,
 		    withname ? tapename : NULL, csv))
 			goto err4;
 
