@@ -1,4 +1,4 @@
-#include "bsdtar_platform.h"
+#include "platform.h"
 
 #include <stdint.h>
 #include <stdio.h>
@@ -421,7 +421,7 @@ phase4(STORAGE_D * SD, STORAGE_R * SR, CHUNKS_S * C,
 				goto err0;
 			break;
 		}
-	};
+	}
 
 	/* Success! */
 	return (0);
