@@ -1,11 +1,10 @@
-#include "bsdtar_platform.h"
+#include "platform.h"
 
 #include <stddef.h>
 #include <stdint.h>
 #include <stdlib.h>
 
 #include "storage.h"
-#include "warnp.h"
 
 #include "multitape.h"
 
