@@ -1,4 +1,4 @@
-#include "bsdtar_platform.h"
+#include "platform.h"
 
 #include <fcntl.h>
 #include <stdint.h>
@@ -110,7 +110,7 @@ statstape_printglobal(TAPE_S * d, const char * csv_filename)
 		csv = 1;
 
 	/* Open CSV output file, if requested. */
-	if (csv && (output = fopen(csv_filename, "wt")) == NULL)
+	if (csv && (output = fopen(csv_filename, "w")) == NULL)
 		goto err0;
 
 	/* Ask the chunk storage layer to do this. */
@@ -133,7 +133,7 @@ err0:
 }
 
 /**
- * statstape_printall(d):
+ * statstape_printall(d, csv_filename):
  * Print statistics relating to each of the archives in a set.  If
  * ${csv_filename} is not NULL, output will be written in CSV format to that
  * filename.
@@ -184,7 +184,7 @@ statstape_printall(TAPE_S * d, const char * csv_filename)
 
 		/* Free parsed metadata. */
 		multitape_metadata_free(&tmd);
-	};
+	}
 
 	/* Free the list of files. */
 	free(flist);
@@ -210,8 +210,8 @@ err0:
 
 /**
  * statstape_printlist(d, verbose):
- * Print the names of each of the archives in a set.  If verbose > 0, print
- * the creation times; if verbose > 1, print the argument vector of the
+ * Print the names of each of the archives in a set.  If ${verbose} > 0, print
+ * the creation times; if ${verbose} > 1, print the argument vector of the
  * program invocation which created the archive.
  */
 int
@@ -278,7 +278,7 @@ statstape_printlist(TAPE_S * d, int verbose)
 
 		/* Free parsed metadata. */
 		multitape_metadata_free(&tmd);
-	};
+	}
 
 	/* Free the list of files. */
 	free(flist);
