@@ -1,4 +1,4 @@
-#include "bsdtar_platform.h"
+#include "platform.h"
 
 #include <sys/file.h>
 #include <sys/stat.h>
@@ -13,6 +13,7 @@
 #include <string.h>
 #include <unistd.h>
 
+#include "asprintf.h"
 #include "chunks.h"
 #include "crypto_entropy.h"
 #include "dirutil.h"
