@@ -1,4 +1,4 @@
-#include "bsdtar_platform.h"
+#include "platform.h"
 
 #include <assert.h>
 #include <limits.h>
@@ -9,6 +9,7 @@
 #include <time.h>
 #include <unistd.h>
 
+#include "asprintf.h"
 #include "chunkify.h"
 #include "chunks.h"
 #include "crypto.h"
@@ -415,6 +416,9 @@ writetape_open(uint64_t machinenum, const char * cachedir,
 		goto err0;
 	memset(d, 0, sizeof(struct multitape_write_internal));
 
+	/* Initialize lockfd as "not locked". */
+	d->lockfd = -1;
+
 	/* Tape starts in "end of entry" mode. */
 	d->mode = 2;
 
@@ -527,7 +531,8 @@ err6:
 err5:
 	storage_write_free(d->S);
 err4:
-	close(d->lockfd);
+	if (d->lockfd != -1)
+		close(d->lockfd);
 err3:
 	free(d->cachedir);
 err2:
@@ -678,7 +683,7 @@ err0:
 
 /**
  * writetape_setmode(d, mode):
- * Set the tape mode to 0 (HEADER) or 1 (DATA).
+ * Set the tape mode to 0 (HEADER), 1 (DATA), or 2 (finished archive entry).
  */
 int
 writetape_setmode(TAPE_W * d, int mode)
@@ -942,7 +947,7 @@ writetape_close(TAPE_W * d)
 
 	/* Print statistics, if we've been asked to do so. */
 	if (d->stats_enabled) {
-		if (csv && (output = fopen(d->csv_filename, "wt")) == NULL)
+		if (csv && (output = fopen(d->csv_filename, "w")) == NULL)
 			goto err2;
 		if (chunks_write_printstats(output, d->C, csv))
 			goto err3;
@@ -971,8 +976,9 @@ writetape_close(TAPE_W * d)
 			goto err1;
 	}
 
-	/* Unlock the cache directory. */
-	close(d->lockfd);
+	/* Unlock the cache directory (if applicable). */
+	if (d->lockfd != -1)
+		close(d->lockfd);
 
 	/* Free memory. */
 	chunkify_free(d->c_file);
@@ -994,7 +1000,8 @@ err2:
 	chunks_write_free(d->C);
 	storage_write_free(d->S);
 err1:
-	close(d->lockfd);
+	if (d->lockfd != -1)
+		close(d->lockfd);
 	chunkify_free(d->c_file);
 	bytebuf_free(d->hbuf);
 	stream_free(&d->t);
@@ -1022,7 +1029,8 @@ writetape_free(TAPE_W * d)
 
 	chunks_write_free(d->C);
 	storage_write_free(d->S);
-	close(d->lockfd);
+	if (d->lockfd != -1)
+		close(d->lockfd);
 	chunkify_free(d->c_file);
 	bytebuf_free(d->hbuf);
 	stream_free(&d->t);
