@@ -1,4 +1,4 @@
-#include "bsdtar_platform.h"
+#include "platform.h"
 
 #include <stdint.h>
 #include <stdlib.h>
@@ -291,7 +291,10 @@ err0:
 
 /**
  * storage_transaction_start(NPC, machinenum, lastseq, seqnum, type):
- * Start a transaction of type ${type}.
+ * Start a transaction of type ${type}, for which 0 indicates a
+ * write transaction, 1 indicates a delete transaction, 2
+ * indicates a fsck with the delete key, and 3 indicates a fsck
+ * with the write key.
  */
 static int
 storage_transaction_start(NETPACKET_CONNECTION * NPC, uint64_t machinenum,
@@ -329,16 +332,27 @@ storage_transaction_start(NETPACKET_CONNECTION * NPC, uint64_t machinenum,
 		warn0("Sequence number mismatch: Run --fsck");
 		goto err0;
 	case 2:
-		/* We should only get this for a write transaction start. */
-		if (type != 0) {
+		/* Non-positive balance.  What operation were we attempting? */
+		switch (type) {
+		case 0:
+			/* Write transaction. */
+			warn0("Cannot start write transaction: "
+			    "Account balance is not positive.");
+			warn0("Please add more money to your tarsnap account");
+			goto err0;
+		case 3:
+			/* --fsck transaction using the write key. */
+			warn0("Could not begin fsck: "
+			    "Account balance is not positive");
+			warn0("Please add more money to your tarsnap account");
+			goto err0;
+		default:
+			/* We don't expect account balance for other ops. */
+			warn0("Programmer error: "
+			    "Unexpected account balance error");
 			netproto_printerr(NETPROTO_STATUS_PROTERR);
 			goto err0;
 		}
-
-		warn0("Cannot start write transaction: "
-		    "Account balance is not positive.");
-		warn0("Please add more money to your tarsnap account");
-		goto err0;
 	default:
 		netproto_printerr(NETPROTO_STATUS_PROTERR);
 		goto err0;
@@ -496,7 +510,8 @@ storage_transaction_start_delete(NETPACKET_CONNECTION * NPC,
 /**
  * storage_transaction_start_fsck(NPC, machinenum, seqnum, whichkey):
  * Start a fsck transaction, and return the sequence number of the new
- * transaction in ${seqnum}.  Use the key specified by whichkey.
+ * transaction in ${seqnum}.  If ${whichkey} is zero, use the
+ * write key; otherwise, use the delete key.
  */
 int
 storage_transaction_start_fsck(NETPACKET_CONNECTION * NPC,
