@@ -191,17 +191,18 @@ truncate_archive(struct bsdtar *bsdtar)
 
 /* If the --disk-pause option was used, sleep for a while. */
 static void
-disk_pause(struct bsdtar *bsdtar)
+disk_pause(int pause_ms)
 {
 	struct timespec ts;
 
 	/* Do we want to sleep? */
-	if (bsdtar->disk_pause == 0)
+	if (pause_ms == 0)
 		return;
 
 	/* Sleep. */
-	ts.tv_sec = bsdtar->disk_pause / 1000;
-	ts.tv_nsec = bsdtar->disk_pause * 1000000;
+	ts.tv_sec = pause_ms / 1000;
+	pause_ms -= ts.tv_sec * 1000;
+	ts.tv_nsec = pause_ms * 1000000;
 	nanosleep(&ts, NULL);
 }
 
@@ -306,8 +307,11 @@ tarsnap_mode_c(struct bsdtar *bsdtar)
 	if ((bsdtar->cachecrunch < 2) && (bsdtar->cachedir != NULL)) {
 		bsdtar->chunk_cache = ccache_read(bsdtar->cachedir);
 		if (bsdtar->chunk_cache == NULL) {
-			bsdtar_warnc(bsdtar, errno, "Error reading cache");
-			goto err1;
+			bsdtar_warnc(bsdtar, errno, "Error reading cache;"
+			    " continuing without it");
+
+			/* Pretend that we were given --verylowmem. */
+			bsdtar->cachecrunch = 2;
 		}
 	}
 
@@ -460,6 +464,13 @@ write_archive(struct archive *a, struct bsdtar *bsdtar)
 		bsdtar_warnc(bsdtar, 0, "Warning: Archive contains no files");
 	}
 
+	/* Always print a final message with --progress-bytes. */
+	if (bsdtar->option_progress_bytes != 0)
+		raise(SIGUSR1);
+
+	/* Print a final update (if desired). */
+	siginfo_printinfo(bsdtar, 0, 1);
+
 	if (archive_write_close(a)) {
 		bsdtar_warnc(bsdtar, 0, "%s", archive_error_string(a));
 		bsdtar->return_value = 1;
@@ -610,7 +621,7 @@ append_archive(struct bsdtar *bsdtar, struct archive *a, struct archive *ina,
 		if (checkpoint_archive(bsdtar, 0))
 			exit(1);
 		if (cookie == NULL)
-			disk_pause(bsdtar);
+			disk_pause(bsdtar->disk_pause);
 		if (network_select(0))
 			exit(1);
 
@@ -622,13 +633,18 @@ append_archive(struct bsdtar *bsdtar, struct archive *a, struct archive *ina,
 		if (bsdtar->option_interactive &&
 		    !yes("copy '%s'", archive_entry_pathname(in_entry)))
 			continue;
-		if (bsdtar->verbose)
+		if (bsdtar->verbose > 1) {
+			safe_fprintf(stderr, "a ");
+			list_item_verbose(bsdtar, stderr, in_entry);
+		} else if (bsdtar->verbose > 0)
 			safe_fprintf(stderr, "a %s",
 			    archive_entry_pathname(in_entry));
 		siginfo_setinfo(bsdtar, "copying",
 		    archive_entry_pathname(in_entry),
-		    archive_entry_size(in_entry));
-		siginfo_printinfo(bsdtar, 0);
+		    archive_entry_size(in_entry),
+		    archive_file_count(a),
+		    archive_position_uncompressed(a));
+		siginfo_printinfo(bsdtar, 0, 0);
 
 		if (MODE_HEADER(bsdtar, a))
 			goto err_fatal;
@@ -685,6 +701,10 @@ err_fatal:
 		exit(1);
 	}
 
+	/* We're not processing any more files. */
+	siginfo_setinfo(bsdtar, NULL, NULL, 0, archive_file_count(a),
+	    archive_position_uncompressed(a));
+
 	/* Note: If we got here, we saw no write errors, so return success. */
 	return (0);
 }
@@ -699,11 +719,11 @@ copy_file_data(struct bsdtar *bsdtar, struct archive *a, struct archive *ina)
 
 	bytes_read = archive_read_data(ina, bsdtar->buff, FILEDATABUFLEN);
 	while (bytes_read > 0) {
-		disk_pause(bsdtar);
+		disk_pause(bsdtar->disk_pause);
 		if (network_select(0))
 			return (-1);
 
-		siginfo_printinfo(bsdtar, progress);
+		siginfo_printinfo(bsdtar, progress, 0);
 
 		bytes_written = archive_write_data(a, bsdtar->buff,
 		    bytes_read);
@@ -759,7 +779,7 @@ write_hierarchy(struct bsdtar *bsdtar, struct archive *a, const char *path)
 			break;
 		if (checkpoint_archive(bsdtar, 0))
 			exit(1);
-		disk_pause(bsdtar);
+		disk_pause(bsdtar->disk_pause);
 		if (network_select(0))
 			exit(1);
 
@@ -971,11 +991,15 @@ write_hierarchy(struct bsdtar *bsdtar, struct archive *a, const char *path)
 		if (S_ISSOCK(st->st_mode))
 			continue;
 
-		/* Display entry as we process it.
-		 * This format is required by SUSv2. */
-		if (bsdtar->verbose)
+		/* Display entry as we process it. */
+		if (bsdtar->verbose > 1) {
+			safe_fprintf(stderr, "a ");
+			list_item_verbose(bsdtar, stderr, entry);
+		} else if (bsdtar->verbose > 0) {
+		/* This format is required by SUSv2. */
 			safe_fprintf(stderr, "a %s",
 			    archive_entry_pathname(entry));
+		}
 
 		/*
 		 * If the user hasn't specifically asked to have the access
@@ -993,11 +1017,13 @@ write_hierarchy(struct bsdtar *bsdtar, struct archive *a, const char *path)
 
 		/* Record what we're doing, for SIGINFO / SIGUSR1. */
 		siginfo_setinfo(bsdtar, "adding",
-		    archive_entry_pathname(entry), archive_entry_size(entry));
+		    archive_entry_pathname(entry), archive_entry_size(entry),
+		    archive_file_count(a),
+		    archive_position_uncompressed(a));
 		archive_entry_linkify(bsdtar->resolver, &entry, &spare_entry);
 
 		/* Handle SIGINFO / SIGUSR1 request if one was made. */
-		siginfo_printinfo(bsdtar, 0);
+		siginfo_printinfo(bsdtar, 0, 0);
 
 		while (entry != NULL) {
 			write_entry_backend(bsdtar, a, entry, st,
@@ -1013,6 +1039,10 @@ write_hierarchy(struct bsdtar *bsdtar, struct archive *a, const char *path)
 	archive_entry_free(entry);
 	if (tree_close(tree))
 		bsdtar_errc(bsdtar, 1, 0, "Error traversing directory tree");
+
+	/* We're not processing any more files. */
+	siginfo_setinfo(bsdtar, NULL, NULL, 0, archive_file_count(a),
+	    archive_position_uncompressed(a));
 }
 
 /*
@@ -1065,11 +1095,16 @@ write_entry_backend(struct bsdtar *bsdtar, struct archive *a,
 	}
 	e = archive_write_header(a, entry);
 	if (e != ARCHIVE_OK) {
-		if (!bsdtar->verbose)
+		if (bsdtar->verbose > 1) {
+			safe_fprintf(stderr, "a ");
+			list_item_verbose(bsdtar, stderr, entry);
+			bsdtar_warnc(bsdtar, 0, ": %s",
+			    archive_error_string(a));
+		} else if (bsdtar->verbose > 0) {
 			bsdtar_warnc(bsdtar, 0, "%s: %s",
 			    archive_entry_pathname(entry),
 			    archive_error_string(a));
-		else
+		} else
 			fprintf(stderr, ": %s", archive_error_string(a));
 	}
 
@@ -1179,11 +1214,11 @@ write_file_data(struct bsdtar *bsdtar, struct archive *a,
 
 	bytes_read = read(fd, bsdtar->buff, FILEDATABUFLEN);
 	while (bytes_read > 0) {
-		disk_pause(bsdtar);
+		disk_pause(bsdtar->disk_pause);
 		if (network_select(0))
 			return (-1);
 
-		siginfo_printinfo(bsdtar, progress);
+		siginfo_printinfo(bsdtar, progress, 0);
 
 		bytes_written = archive_write_data(a, bsdtar->buff,
 		    bytes_read);
